@@ -22,6 +22,14 @@ extern void totempluginviewer_marshal_VOID__UINT_UINT_STRING (GClosure     *clos
                                                               gpointer      invocation_hint,
                                                               gpointer      marshal_data);
 
+/* VOID:STRING,BOXED (totempluginviewer-marshal.list:3) */
+extern void totempluginviewer_marshal_VOID__STRING_BOXED (GClosure     *closure,
+                                                          GValue       *return_value,
+                                                          guint         n_param_values,
+                                                          const GValue *param_values,
+                                                          gpointer      invocation_hint,
+                                                          gpointer      marshal_data);
+
 G_END_DECLS
 
 #endif /* __totempluginviewer_marshal_MARSHAL_H__ */
