@@ -57,7 +57,6 @@
 #include "totem-screenshot.h"
 #include "totem-sidebar.h"
 #include "totem-menu.h"
-#include "totem-missing-plugins.h"
 #include "totem-options.h"
 #include "totem-uri.h"
 #include "totem-interface.h"
@@ -569,7 +568,6 @@ totem_action_load_media_device (Totem *totem, const char *device)
 					    _("Please consider using a music player or a CD extractor to play this CD"),
 					    totem);
 			retval = FALSE;
-			break;
 		default:
 			g_assert_not_reached ();
 	}
@@ -3008,8 +3006,6 @@ video_widget_create (Totem *totem)
 			G_CALLBACK (on_error_event),
 			totem);
 
-	totem_missing_plugins_setup (totem);
-
 	container = GTK_CONTAINER (gtk_builder_get_object (totem->xml, "tmw_bvw_box"));
 	gtk_container_add (container,
 			GTK_WIDGET (totem->bvw));
